@@ -1,4 +1,4 @@
-## ---- echo = FALSE, message = FALSE-------------------------------------------
+## ----echo = FALSE, message = FALSE--------------------------------------------
 knitr::opts_chunk$set(collapse = T, comment = "#>")
 options(tibble.print_min = 4L, tibble.print_max = 4L)
 set.seed(1014)
@@ -6,17 +6,17 @@ set.seed(1014)
 ## ----setup, message = FALSE---------------------------------------------------
 library(dplyr)
 
-## ---- results = FALSE---------------------------------------------------------
+## ----results = FALSE----------------------------------------------------------
 starwars[starwars$homeworld == "Naboo" & starwars$species == "Human", ,]
 
-## ---- results = FALSE---------------------------------------------------------
+## ----results = FALSE----------------------------------------------------------
 starwars %>% filter(homeworld == "Naboo", species == "Human")
 
 ## -----------------------------------------------------------------------------
 df <- data.frame(x = runif(3), y = runif(3))
 df$x
 
-## ---- results = FALSE---------------------------------------------------------
+## ----results = FALSE----------------------------------------------------------
 var_summary <- function(data, var) {
   data %>%
     summarise(n = n(), min = min({{ var }}), max = max({{ var }}))
@@ -25,12 +25,23 @@ mtcars %>%
   group_by(cyl) %>% 
   var_summary(mpg)
 
-## ---- results = FALSE---------------------------------------------------------
+## ----results = FALSE----------------------------------------------------------
 for (var in names(mtcars)) {
   mtcars %>% count(.data[[var]]) %>% print()
 }
 
-## ---- results = FALSE---------------------------------------------------------
+## -----------------------------------------------------------------------------
+name <- "susan"
+tibble("{name}" := 2)
+
+## -----------------------------------------------------------------------------
+my_df <- function(x) {
+  tibble("{{x}}_2" := x * 2)
+}
+my_var <- 10
+my_df(my_var)
+
+## ----results = FALSE----------------------------------------------------------
 summarise_mean <- function(data, vars) {
   data %>% summarise(n = n(), across({{ vars }}, mean))
 }
@@ -38,7 +49,7 @@ mtcars %>%
   group_by(cyl) %>% 
   summarise_mean(where(is.numeric))
 
-## ---- results = FALSE---------------------------------------------------------
+## ----results = FALSE----------------------------------------------------------
 vars <- c("mpg", "vs")
 mtcars %>% select(all_of(vars))
 mtcars %>% select(!all_of(vars))
@@ -48,23 +59,6 @@ mutate_y <- function(data) {
   mutate(data, y = a + x)
 }
 
-## -----------------------------------------------------------------------------
-my_summary_function <- function(data) {
-  data %>% 
-    filter(x > 0) %>% 
-    group_by(grp) %>% 
-    summarise(y = mean(y), n = n())
-}
-
-## -----------------------------------------------------------------------------
-#' @importFrom rlang .data
-my_summary_function <- function(data) {
-  data %>% 
-    filter(.data$x > 0) %>% 
-    group_by(.data$grp) %>% 
-    summarise(y = mean(.data$y), n = n())
-}
-
 ## -----------------------------------------------------------------------------
 my_summarise <- function(data, group_var) {
   data %>%
@@ -113,6 +107,37 @@ my_summarise <- function(.data, ...) {
 starwars %>% my_summarise(homeworld)
 starwars %>% my_summarise(sex, gender)
 
+## -----------------------------------------------------------------------------
+quantile_df <- function(x, probs = c(0.25, 0.5, 0.75)) {
+  tibble(
+    val = quantile(x, probs),
+    quant = probs
+  )
+}
+
+x <- 1:5
+quantile_df(x)
+
+## -----------------------------------------------------------------------------
+df <- tibble(
+  grp = rep(1:3, each = 10),
+  x = runif(30),
+  y = rnorm(30)
+)
+
+df %>%
+  group_by(grp) %>%
+  summarise(quantile_df(x, probs = .5))
+
+df %>%
+  group_by(grp) %>%
+  summarise(across(x:y, ~ quantile_df(.x, probs = .5), .unpack = TRUE))
+
+## -----------------------------------------------------------------------------
+df %>%
+  group_by(grp) %>%
+  reframe(across(x:y, quantile_df, .unpack = TRUE))
+
 ## -----------------------------------------------------------------------------
 my_summarise <- function(data, summary_vars) {
   data %>%
@@ -125,28 +150,28 @@ starwars %>%
 ## -----------------------------------------------------------------------------
 my_summarise <- function(data, group_var, summarise_var) {
   data %>%
-    group_by(across({{ group_var }})) %>% 
+    group_by(pick({{ group_var }})) %>% 
     summarise(across({{ summarise_var }}, mean))
 }
 
 ## -----------------------------------------------------------------------------
 my_summarise <- function(data, group_var, summarise_var) {
   data %>%
-    group_by(across({{ group_var }})) %>% 
+    group_by(pick({{ group_var }})) %>% 
     summarise(across({{ summarise_var }}, mean, .names = "mean_{.col}"))
 }
 
-## ---- results = FALSE---------------------------------------------------------
+## ----results = FALSE----------------------------------------------------------
 for (var in names(mtcars)) {
   mtcars %>% count(.data[[var]]) %>% print()
 }
 
-## ---- results = FALSE---------------------------------------------------------
+## ----results = FALSE----------------------------------------------------------
 mtcars %>% 
   names() %>% 
   purrr::map(~ count(mtcars, .data[[.x]]))
 
-## ---- eval = FALSE------------------------------------------------------------
+## ----eval = FALSE-------------------------------------------------------------
 #  library(shiny)
 #  ui <- fluidPage(
 #    selectInput("var", "Variable", choices = names(diamonds)),
