@@ -1,5 +1,3 @@
-context("colwise filter")
-
 test_that("filter_if()", {
   expect_identical(nrow(filter_if(mtcars, is_integerish, all_vars(. > 1))), 0L)
   expect_identical(nrow(filter_if(mtcars, is_integerish, all_vars(. > 0))), 7L)
@@ -64,11 +62,25 @@ test_that("colwise filter support .data$. in the quosure versions", {
 })
 
 
+test_that("all_exprs() creates intersection", {
+  expect_identical(all_exprs(am == 1), quo(am == 1))
+
+  quo <- set_env(quo((!!quo(cyl == 2)) & (!!quo(am == 1))), base_env())
+  expect_identical(all_exprs(cyl == 2, am == 1), quo)
+})
+
+test_that("any_exprs() creates union", {
+  expect_identical(any_exprs(am == 1), quo(am == 1))
+
+  quo <- set_env(quo((!!quo(cyl == 2)) | (!!quo(am == 1))), base_env())
+  expect_identical(any_exprs(cyl == 2, am == 1), quo)
+})
+
 # Errors ------------------------------------------------------------------
 
 test_that("colwise filter() give meaningful errors", {
-  verify_output(test_path("test-colwise-filter-errors.txt"), {
-    filter_if(mtcars, is_character, all_vars(. > 0))
-    filter_all(mtcars, list(~. > 0))
+  expect_snapshot({
+    (expect_error(filter_if(mtcars, is_character, all_vars(. > 0))))
+    (expect_error(filter_all(mtcars, list(~ . > 0))))
   })
 })
