@@ -90,6 +90,9 @@ test_that(".dot argument works correctly (PR #2110)", {
   )
 })
 
+test_that("`recode()` signals that it is superseded", {
+  expect_snapshot(catch_cnd(recode("a", a = "A")))
+})
 
 # factor ------------------------------------------------------------------
 
@@ -146,6 +149,10 @@ test_that("can recode factor with redundant levels", {
   )
 })
 
+test_that("`recode_factor()` signals that it is superseded", {
+  expect_snapshot(catch_cnd(recode_factor("a", a = "A")))
+})
+
 # Errors --------------------------------------------
 
 test_that("recode() gives meaningful error messages", {
